<template>
    <Head title="Tracer Study"></Head>
    <StudentLayout>
        <div class="card">
            <div class="card-body">
                <form @submit.prevent="submitForm">
                    <BaseDropDown
                        v-model="form.status"
                        label="Status"
                        placeholder="-- Pilih Status --"
                        :options="optionsStatus"
                        :error-message="form.errors.status"
                    />
                    <BaseInput
                        v-model="form.institution_name"
                        name="institution_name"
                        label="Nama Institusi"
                        placeholder="Masukkan Nama Institusi"
                        :error-message="form.errors.institution_name"
                    />
                    <BaseInput
                        v-model="form.position_or_major"
                        name="position_or_major"
                        label="Posisi/Jurusan"
                        placeholder="Masukkan Posisi/Jurusan"
                        :error-message="form.errors.position_or_major"
                    />
                    <BaseTextArea
                        v-model="form.description"
                        name="description"
                        label="Deskripsi"
                        placeholder="Masukkan Deskripsi"
                        :error-message="form.errors.description"
                    />
                    <div class="text-end">
                        <BaseButton
                            type="submit"
                            class="btn-primary"
                        >
                            Simpan
                        </BaseButton>
                    </div>
                </form>
            </div>
        </div>

        <div class="card mt-5">
            <div class="card-body">
                <div class="card-title">
                    Histori Tracer Study
                </div>
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th scope="col">No</th>
                            <th scope="col">Status</th>
                            <th scope="col">Nama Institusi</th>
                            <th scope="col">Posisi/Jurusan</th>
                            <th scope="col">Tgl Diunggah</th>
                            <th scope="col">Action</th>
                        </tr>
                    </thead>
                    <tbody>
                        <tr v-for="(item, index) in tracer_studies" :key="index">
                            <td>{{ index + 1 }}</td>
                            <td>{{ item.status }}</td>
                            <td>{{ item.institution_name }}</td>
                            <td>{{ item.position_or_major }}</td>
                            <td>{{ moment(item.created_at).format('DD/MM/YYYY H:mm:ss') }}</td>
                            <td>
                                <BaseButton
                                    class="btn-danger btn-sm"
                                    @click="showConfirmDelete = item.id"
                                >
                                    <i class="ti ti-trash"></i>
                                </BaseButton>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </div>
        </div>
    </StudentLayout>

    <BaseConfirmation
        :is-visible="showConfirmDelete"
        @confirmed="deleteTracerStudy"
        @close="showConfirmDelete = null"
        title="Konfirmasi Hapus"
        message="Apakah Anda yakin ingin menghapus tracer study ini?"
        />

</template>

<script setup>
import {Head, useForm} from '@inertiajs/vue3';
import StudentLayout from "@/Layouts/StudentLayout.vue";
import BaseInput from "@/Components/Forms/BaseInput.vue";
import BaseDropDown from "@/Components/Forms/BaseDropDown.vue";
import {ref} from "vue";
import BaseTextArea from "@/Components/Forms/BaseTextArea.vue";
import BaseConfirmation from "@/Components/Modal/BaseConfirmation.vue";
import BaseButton from "@/Components/Button/BaseButton.vue";
import moment from "moment";
const showConfirmDelete = ref(null);

const form = useForm({
    description: '',
    institution_name: '',
    position_or_major: '',
    status: '',
})
const optionsStatus = ref([
    {label: 'Bekerja', value: 'bekerja'},
    {label: 'Melanjutkan Studi', value: 'kuliah'},
    {label: 'Wirausaha', value: 'wirausaha'},
    {label: 'Lainnya', value: 'lainnya'},
])
const props = defineProps({
    tracer_studies: {
        type: Array,
        required: true
    }
})

const submitForm = () => {
    form.post('/user/tracer-study', {
        preserveScroll: true,
        onSuccess: () => {
            form.reset();
        }
    });
}
const deleteTracerStudy = () => {
    form.delete(`/user/tracer-study/${showConfirmDelete.value}`, {
        preserveScroll: true,
        onSuccess: () => {
            form.reset();
        }
    });
}
</script>
